@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * GData Client
- * Copyright (C) Philip Withnall 2009 <philip@tecnocode.co.uk>
+ * Copyright (C) Philip Withnall 2009–2010 <philip@tecnocode.co.uk>
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -107,7 +107,7 @@ gdata_link_class_init (GDataLinkClass *klass)
 	g_object_class_install_property (gobject_class, PROP_RELATION_TYPE,
 				g_param_spec_string ("relation-type",
 					"Relation type", "The link relation type.",
-					"http://www.iana.org/assignments/relation/alternate",
+					GDATA_LINK_ALTERNATE,
 					G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
@@ -181,7 +181,7 @@ gdata_link_init (GDataLink *self)
 {
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GDATA_TYPE_LINK, GDataLinkPrivate);
 	self->priv->length = -1;
-	self->priv->relation_type = g_strdup ("http://www.iana.org/assignments/relation/alternate");
+	self->priv->relation_type = g_strdup (GDATA_LINK_ALTERNATE);
 }
 
 static void
@@ -264,15 +264,16 @@ gdata_link_set_property (GObject *object, guint property_id, const GValue *value
 static gboolean
 pre_parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *root_node, gpointer user_data, GError **error)
 {
-	xmlChar *uri, *relation_type, *content_type, *language, *title, *length;
+	xmlChar *uri, *relation_type, *content_type, *language, *length;
 	GDataLink *self = GDATA_LINK (parsable);
 
 	/* href */
 	uri = xmlGetProp (root_node, (xmlChar*) "href");
-	if (uri == NULL && *uri != '\0')
+	if (uri == NULL || *uri == '\0') {
+		xmlFree (uri);
 		return gdata_parser_error_required_property_missing (root_node, "href", error);
-	self->priv->uri = g_strdup ((gchar*) uri);
-	xmlFree (uri);
+	}
+	self->priv->uri = (gchar*) uri;
 
 	/* rel */
 	relation_type = xmlGetProp (root_node, (xmlChar*) "rel");
@@ -290,8 +291,7 @@ pre_parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *root_node, gpointe
 		xmlFree (content_type);
 		return gdata_parser_error_required_property_missing (root_node, "type", error);
 	}
-	self->priv->content_type = g_strdup ((gchar*) content_type);
-	xmlFree (content_type);
+	self->priv->content_type = (gchar*) content_type;
 
 	/* hreflang */
 	language = xmlGetProp (root_node, (xmlChar*) "hreflang");
@@ -299,13 +299,10 @@ pre_parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *root_node, gpointe
 		xmlFree (language);
 		return gdata_parser_error_required_property_missing (root_node, "hreflang", error);
 	}
-	self->priv->language = g_strdup ((gchar*) language);
-	xmlFree (language);
+	self->priv->language = (gchar*) language;
 
 	/* title */
-	title = xmlGetProp (root_node, (xmlChar*) "title");
-	self->priv->title = g_strdup ((gchar*) title);
-	xmlFree (title);
+	self->priv->title = (gchar*) xmlGetProp (root_node, (xmlChar*) "title");
 
 	/* length */
 	length = xmlGetProp (root_node, (xmlChar*) "length");
@@ -313,6 +310,7 @@ pre_parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *root_node, gpointe
 		self->priv->length = -1;
 	else
 		self->priv->length = strtoul ((gchar*) length, NULL, 10);
+	xmlFree (length);
 
 	return TRUE;
 }
@@ -322,18 +320,10 @@ pre_get_xml (GDataParsable *parsable, GString *xml_string)
 {
 	GDataLinkPrivate *priv = GDATA_LINK (parsable)->priv;
 
-	{
-		gchar *href = g_markup_escape_text (priv->uri, -1);
-		g_string_append_printf (xml_string, " href='%s'", href);
-		g_free (href);
-	}
-
-	if (priv->title != NULL) {
-		gchar *link_title = g_markup_escape_text (priv->title, -1);
-		g_string_append_printf (xml_string, " title='%s'", link_title);
-		g_free (link_title);
-	}
+	gdata_parser_string_append_escaped (xml_string, " href='", priv->uri, "'");
 
+	if (priv->title != NULL)
+		gdata_parser_string_append_escaped (xml_string, " title='", priv->title, "'");
 	if (priv->relation_type != NULL)
 		g_string_append_printf (xml_string, " rel='%s'", priv->relation_type);
 	if (priv->content_type != NULL)
@@ -382,7 +372,7 @@ gdata_link_compare (const GDataLink *a, const GDataLink *b)
 {
 	if (a == NULL && b != NULL)
 		return -1;
-	else if (b == NULL)
+	else if (a != NULL && b == NULL)
 		return 1;
 
 	if (a == b)
@@ -475,7 +465,7 @@ gdata_link_set_relation_type (GDataLink *self, const gchar *relation_type)
 	 */
 	g_free (self->priv->relation_type);
 	if (relation_type == NULL)
-		self->priv->relation_type = g_strdup ("http://www.iana.org/assignments/relation/alternate");
+		self->priv->relation_type = g_strdup (GDATA_LINK_ALTERNATE);
 	else if (strchr ((char*) relation_type, ':') == NULL)
 		self->priv->relation_type = g_strconcat ("http://www.iana.org/assignments/relation/", (const gchar*) relation_type, NULL);
 	else
