@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * GData Client
- * Copyright (C) Philip Withnall 2009 <philip@tecnocode.co.uk>
+ * Copyright (C) Philip Withnall 2009–2010 <philip@tecnocode.co.uk>
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,7 +24,7 @@
  * @include: gdata/gd/gdata-gd-phone-number.h
  *
  * #GDataGDPhoneNumber represents a "phoneNumber" element from the
- * <ulink type="http" url="http://code.google.com/apis/gdata/docs/1.0/elements.html#gdPhoneNumber">GData specification</ulink>.
+ * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdPhoneNumber">GData specification</ulink>.
  **/
 
 #include <glib.h>
@@ -89,7 +89,7 @@ gdata_gd_phone_number_class_init (GDataGDPhoneNumberClass *klass)
 	 * Human-readable phone number; may be in any telephone number format.
 	 *
 	 * For more information, see the
-	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/1.0/elements.html#gdPhoneNumber">GData specification</ulink>.
+	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdPhoneNumber">GData specification</ulink>.
 	 *
 	 * Since: 0.4.0
 	 **/
@@ -105,7 +105,7 @@ gdata_gd_phone_number_class_init (GDataGDPhoneNumberClass *klass)
 	 * An optional "tel URI" used to represent the number in a formal way, useful for programmatic access, such as a VoIP/PSTN bridge.
 	 *
 	 * For more information, see the
-	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/1.0/elements.html#gdPhoneNumber">GData specification</ulink>.
+	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdPhoneNumber">GData specification</ulink>.
 	 *
 	 * Since: 0.4.0
 	 **/
@@ -121,7 +121,7 @@ gdata_gd_phone_number_class_init (GDataGDPhoneNumberClass *klass)
 	 * A programmatic value that identifies the type of phone number.
 	 *
 	 * For more information, see the
-	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/1.0/elements.html#gdPhoneNumber">GData specification</ulink>.
+	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdPhoneNumber">GData specification</ulink>.
 	 *
 	 * Since: 0.4.0
 	 **/
@@ -137,7 +137,7 @@ gdata_gd_phone_number_class_init (GDataGDPhoneNumberClass *klass)
 	 * A simple string value used to name this phone number. It allows UIs to display a label such as "Mobile", "Home", "Work", etc.
 	 *
 	 * For more information, see the
-	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/1.0/elements.html#gdPhoneNumber">GData specification</ulink>.
+	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdPhoneNumber">GData specification</ulink>.
 	 *
 	 * Since: 0.4.0
 	 **/
@@ -153,7 +153,7 @@ gdata_gd_phone_number_class_init (GDataGDPhoneNumberClass *klass)
 	 * Indicates which phone number out of a group is primary.
 	 *
 	 * For more information, see the
-	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/1.0/elements.html#gdPhoneNumber">GData specification</ulink>.
+	 * <ulink type="http" url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdPhoneNumber">GData specification</ulink>.
 	 *
 	 * Since: 0.4.0
 	 **/
@@ -243,7 +243,7 @@ gdata_gd_phone_number_set_property (GObject *object, guint property_id, const GV
 static gboolean
 pre_parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *root_node, gpointer user_data, GError **error)
 {
-	xmlChar *number, *uri, *rel, *label, *primary;
+	xmlChar *number, *rel, *primary;
 	gboolean primary_bool;
 	GDataGDPhoneNumberPrivate *priv = GDATA_GD_PHONE_NUMBER (parsable)->priv;
 
@@ -275,20 +275,13 @@ pre_parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *root_node, gpointe
 	}
 	xmlFree (primary);
 
-	/* Other properties */
-	label = xmlGetProp (root_node, (xmlChar*) "label");
-	uri = xmlGetProp (root_node, (xmlChar*) "uri");
-
 	gdata_gd_phone_number_set_number (GDATA_GD_PHONE_NUMBER (parsable), (gchar*) number);
-	priv->uri = g_strdup ((gchar*) uri);
-	priv->relation_type = g_strdup ((gchar*) rel);
-	priv->label = g_strdup ((gchar*) label);
+	priv->uri = (gchar*) xmlGetProp (root_node, (xmlChar*) "uri");
+	priv->relation_type = (gchar*) rel;
+	priv->label = (gchar*) xmlGetProp (root_node, (xmlChar*) "label");
 	priv->is_primary = primary_bool;
 
 	xmlFree (number);
-	xmlFree (uri);
-	xmlFree (rel);
-	xmlFree (label);
 
 	return TRUE;
 }
@@ -317,11 +310,8 @@ pre_get_xml (GDataParsable *parsable, GString *xml_string)
 		g_string_append_printf (xml_string, " uri='%s'", priv->uri);
 	if (priv->relation_type != NULL)
 		g_string_append_printf (xml_string, " rel='%s'", priv->relation_type);
-	if (priv->label != NULL) {
-		gchar *label = g_markup_escape_text (priv->label, -1);
-		g_string_append_printf (xml_string, " label='%s'", label);
-		g_free (label);
-	}
+	if (priv->label != NULL)
+		gdata_parser_string_append_escaped (xml_string, " label='", priv->label, "'");
 
 	if (priv->is_primary == TRUE)
 		g_string_append (xml_string, " primary='true'");
@@ -332,12 +322,7 @@ pre_get_xml (GDataParsable *parsable, GString *xml_string)
 static void
 get_xml (GDataParsable *parsable, GString *xml_string)
 {
-	gchar *number;
-	GDataGDPhoneNumberPrivate *priv = GDATA_GD_PHONE_NUMBER (parsable)->priv;
-
-	number = g_markup_escape_text (priv->number, -1);
-	g_string_append (xml_string, number);
-	g_free (number);
+	gdata_parser_string_append_escaped (xml_string, NULL, GDATA_GD_PHONE_NUMBER (parsable)->priv->number, NULL);
 }
 
 static void
@@ -356,7 +341,7 @@ get_namespaces (GDataParsable *parsable, GHashTable *namespaces)
  * @is_primary: %TRUE if this phone number is its owner's primary number, %FALSE otherwise
  *
  * Creates a new #GDataGDPhoneNumber. More information is available in the <ulink type="http"
- * url="http://code.google.com/apis/gdata/docs/1.0/elements.html#gdPhoneNumber">GData specification</ulink>.
+ * url="http://code.google.com/apis/gdata/docs/2.0/elements.html#gdPhoneNumber">GData specification</ulink>.
  *
  * Return value: a new #GDataGDPhoneNumber, or %NULL; unref with g_object_unref()
  *
@@ -426,23 +411,13 @@ gdata_gd_phone_number_get_number (GDataGDPhoneNumber *self)
 void
 gdata_gd_phone_number_set_number (GDataGDPhoneNumber *self, const gchar *number)
 {
-	gint len;
-
 	g_return_if_fail (GDATA_IS_GD_PHONE_NUMBER (self));
 	g_return_if_fail (number != NULL && *number != '\0');
 
-	g_free (self->priv->number);
-
 	/* Trim leading and trailing whitespace from the number.
 	 * See here: http://code.google.com/apis/gdata/docs/1.0/elements.html#gdPhoneNumber */
-	while (*number != '\0' && g_ascii_isspace (*number))
-		number++;
-
-	len = strlen (number);
-	while (len > 0 && g_ascii_isspace (number[len - 1]))
-		len--;
-
-	self->priv->number = g_strndup (number, len);
+	g_free (self->priv->number);
+	self->priv->number = gdata_parser_utf8_trim_whitespace (number);
 	g_object_notify (G_OBJECT (self), "number");
 }
 
