@@ -24,12 +24,29 @@
 #include <glib-object.h>
 
 #include <gdata/gdata-entry.h>
-#include <gdata/gdata-gdata.h>
-#include <gdata/gdata-media-rss.h>
-#include <gdata/services/youtube/gdata-youtube.h>
+#include <gdata/media/gdata-media-category.h>
+#include <gdata/services/youtube/gdata-youtube-content.h>
+#include <gdata/services/youtube/gdata-youtube-credit.h>
+#include <gdata/services/youtube/gdata-youtube-state.h>
 
 G_BEGIN_DECLS
 
+/**
+ * GDataYouTubeAspectRatio:
+ * @GDATA_YOUTUBE_ASPECT_RATIO_UNKNOWN: unknown aspect ratio
+ * @GDATA_YOUTUBE_ASPECT_RATIO_WIDESCREEN: widescreen (16:9) video
+ *
+ * The aspect ratio of a video. See the
+ * <ulink type="http" url="http://code.google.com/apis/youtube/2.0/reference.html#youtube_data_api_tag_yt:aspectratio">online documentation</ulink>
+ * for more information.
+ *
+ * Since: 0.4.0
+ **/
+typedef enum {
+	GDATA_YOUTUBE_ASPECT_RATIO_UNKNOWN = 0,
+	GDATA_YOUTUBE_ASPECT_RATIO_WIDESCREEN
+} GDataYouTubeAspectRatio;
+
 #define GDATA_TYPE_YOUTUBE_VIDEO		(gdata_youtube_video_get_type ())
 #define GDATA_YOUTUBE_VIDEO(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), GDATA_TYPE_YOUTUBE_VIDEO, GDataYouTubeVideo))
 #define GDATA_YOUTUBE_VIDEO_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), GDATA_TYPE_YOUTUBE_VIDEO, GDataYouTubeVideoClass))
@@ -62,7 +79,6 @@ typedef struct {
 GType gdata_youtube_video_get_type (void) G_GNUC_CONST;
 
 GDataYouTubeVideo *gdata_youtube_video_new (const gchar *id) G_GNUC_WARN_UNUSED_RESULT;
-GDataYouTubeVideo *gdata_youtube_video_new_from_xml (const gchar *xml, gint length, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 
 guint gdata_youtube_video_get_view_count (GDataYouTubeVideo *self);
 guint gdata_youtube_video_get_favorite_count (GDataYouTubeVideo *self);
@@ -70,20 +86,17 @@ const gchar *gdata_youtube_video_get_location (GDataYouTubeVideo *self);
 void gdata_youtube_video_set_location (GDataYouTubeVideo *self, const gchar *location);
 gboolean gdata_youtube_video_get_no_embed (GDataYouTubeVideo *self);
 void gdata_youtube_video_set_no_embed (GDataYouTubeVideo *self, gboolean no_embed);
-GDataGDRating *gdata_youtube_video_get_rating (GDataYouTubeVideo *self);
+void gdata_youtube_video_get_rating (GDataYouTubeVideo *self, guint *min, guint *max, guint *count, gdouble *average);
 const gchar *gdata_youtube_video_get_keywords (GDataYouTubeVideo *self);
 void gdata_youtube_video_set_keywords (GDataYouTubeVideo *self, const gchar *keywords);
 const gchar *gdata_youtube_video_get_player_uri (GDataYouTubeVideo *self);
-GDataMediaRating *gdata_youtube_video_get_media_rating (GDataYouTubeVideo *self);
-GDataMediaRestriction *gdata_youtube_video_get_restriction (GDataYouTubeVideo *self);
-const gchar *gdata_youtube_video_get_title (GDataYouTubeVideo *self);
-void gdata_youtube_video_set_title (GDataYouTubeVideo *self, const gchar *title);
+gboolean gdata_youtube_video_is_restricted_in_country (GDataYouTubeVideo *self, const gchar *country);
 GDataMediaCategory *gdata_youtube_video_get_category (GDataYouTubeVideo *self);
 void gdata_youtube_video_set_category (GDataYouTubeVideo *self, GDataMediaCategory *category);
-GDataMediaCredit *gdata_youtube_video_get_credit (GDataYouTubeVideo *self);
+GDataYouTubeCredit *gdata_youtube_video_get_credit (GDataYouTubeVideo *self);
 const gchar *gdata_youtube_video_get_description (GDataYouTubeVideo *self);
 void gdata_youtube_video_set_description (GDataYouTubeVideo *self, const gchar *description);
-GDataMediaContent *gdata_youtube_video_look_up_content (GDataYouTubeVideo *self, const gchar *type);
+GDataYouTubeContent *gdata_youtube_video_look_up_content (GDataYouTubeVideo *self, const gchar *type);
 GList *gdata_youtube_video_get_thumbnails (GDataYouTubeVideo *self);
 guint gdata_youtube_video_get_duration (GDataYouTubeVideo *self);
 gboolean gdata_youtube_video_is_private (GDataYouTubeVideo *self);
@@ -93,9 +106,12 @@ const gchar *gdata_youtube_video_get_video_id (GDataYouTubeVideo *self);
 gboolean gdata_youtube_video_is_draft (GDataYouTubeVideo *self);
 void gdata_youtube_video_set_is_draft (GDataYouTubeVideo *self, gboolean is_draft);
 GDataYouTubeState *gdata_youtube_video_get_state (GDataYouTubeVideo *self);
-GDataGDFeedLink *gdata_youtube_video_get_comments_feed_link (GDataYouTubeVideo *self);
 void gdata_youtube_video_get_recorded (GDataYouTubeVideo *self, GTimeVal *recorded);
 void gdata_youtube_video_set_recorded (GDataYouTubeVideo *self, GTimeVal *recorded);
+GDataYouTubeAspectRatio gdata_youtube_video_get_aspect_ratio (GDataYouTubeVideo *self);
+void gdata_youtube_video_set_aspect_ratio (GDataYouTubeVideo *self, GDataYouTubeAspectRatio aspect_ratio);
+
+gchar *gdata_youtube_video_get_video_id_from_uri (const gchar *video_uri);
 
 G_END_DECLS
 
